@@ -827,7 +827,7 @@ def unidirectional_transfer_decoding_kfold(data1, labels1, data2, labels2, n=2,
 
         minn2 = int(np.min(ns2) / navg)
 
-        subacc = np.zeros([nrepeats, newnts1, newnts2])
+        subacc = np.zeros([nrepeats, newnts1, newnts2, nfolds])
 
         for i in range(nrepeats):
 
