@@ -63,10 +63,6 @@ def rdm_correlation_spearman(RDM1, RDM2, rescale=False, permutation=False, iter=
     print(np.shape(RDM1))
     print(np.shape(RDM2))
 
-    if fisherz == True:
-        RDM1 = fisherz_rdm(RDM1)
-        RDM2 = fisherz_rdm(RDM2)
-
     if rescale == True:
 
         # flatten the RDM1
