@@ -11,7 +11,7 @@ from neurora.stuff import permutation_test
 
 ' a function for conducting the statistical analysis for results of EEG-like data '
 
-def stats(corrs, permutation=True, iter=5000):
+def stats(corrs, fisherz=True, permutation=True, iter=5000):
 
     """
     Conduct the statistical analysis for results of EEG-like data
@@ -22,6 +22,8 @@ def stats(corrs, permutation=True, iter=5000):
         The correlation coefficients.
         The shape of corrs must be [n_subs, n_chls, n_ts, 2]. n_subs, n_chls, n_ts represent the number of subjects, the
         number of channels and the number of time-points. 2 represents a r-value and a p-value.
+    fisherz : bool True or False. Default is True.
+        Conduct Fisher-Z transform.
     permutation : bool True or False. Default is False.
         Use permutation test or not.
     iter : int. Default is 5000.
@@ -62,14 +64,15 @@ def stats(corrs, permutation=True, iter=5000):
     # calculate the statistical results
     for i in range(chls):
         for j in range(ts):
+
+            if fisherz is True:
+                zs = 0.5 * np.log((1 + rs) / (1 - rs))
+
             # t test
-            stats[i, j] = ttest_1samp(rs[:, i, j], 0)
+            stats[i, j] = ttest_1samp(rs[:, i, j], 0, alternative="greater")
 
             if permutation == True:
 
-                # Fisher r to z
-                zs = 0.5*np.log((1+rs)/(1-rs))
-
                 stats[i, j, 1] = permutation_test(zs[:, i, j], np.zeros([subs]), iter=iter)
 
     return stats
@@ -77,7 +80,7 @@ def stats(corrs, permutation=True, iter=5000):
 
 ' a function for conducting the statistical analysis for results of fMRI data (searchlight) '
 
-def stats_fmri(corrs, permutation=False, iter=5000):
+def stats_fmri(corrs, fisherz=True, permutation=False, iter=5000):
 
     """
     Conduct the statistical analysis for results of fMRI data (searchlight)
@@ -88,6 +91,8 @@ def stats_fmri(corrs, permutation=False, iter=5000):
         The correlation coefficients.
         The shape of corrs must be [n_subs, n_x, n_y, n_z, 2]. n_subs, n_x, n_y, n_z represent the number of subjects,
         the number of calculation units for searchlight along the x, y, z axis and 2 represents a r-value and a p-value.
+    fisherz : bool True or False. Default is True.
+        Conduct Fisher-Z transform.
     permutation : bool True or False. Default is False.
         Use permutation test or not.
     iter : int. Default is 5000.
@@ -130,12 +135,15 @@ def stats_fmri(corrs, permutation=False, iter=5000):
     for i in range(n_x):
         for j in range(n_y):
             for k in range(n_z):
-                # t test
-                stats[i, j, k] = ttest_1samp(rs[:, i, j, k], 0)
 
-                if permutation == True:
+                if fisherz is True:
                     # Fisher r to z
                     zs = 0.5 * np.log((1 + rs) / (1 - rs))
+
+                # t test
+                stats[i, j, k] = ttest_1samp(rs[:, i, j, k], 0, alternative="greater")
+
+                if permutation == True:
                     stats[i, j, k, 1] = permutation_test(zs[:, i, j, k], np.zeros([subs]), iter=iter)
 
     return stats
@@ -143,7 +151,7 @@ def stats_fmri(corrs, permutation=False, iter=5000):
 
 ' a function for conducting the statistical analysis for results of fMRI data (ISC searchlight) '
 
-def stats_iscfmri(corrs, permutation=False, iter=5000):
+def stats_iscfmri(corrs, fisherz=True, permutation=False, iter=5000):
 
     """
     Conduct the statistical analysis for results of fMRI data (ISC searchlight)
@@ -155,6 +163,8 @@ def stats_iscfmri(corrs, permutation=False, iter=5000):
         The shape of corrs must be [n_ts, n_subs!/(2!*(n_subs-2)!), n_x, n_y, n_z, 2]. n_ts, n_subs, n_x, n_y, n_z
         represent the number of subjects, the number of calculation units for searchlight along the x, y, z axis and 2
         represents a r-value and a p-value.
+    fisherz : bool True or False. Default is True.
+        Conduct Fisher-Z transform.
     permutation : bool True or False. Default is False.
         Use permutation test or not.
     iter : int. Default is 5000.
@@ -197,13 +207,16 @@ def stats_iscfmri(corrs, permutation=False, iter=5000):
         for i in range(n_x):
             for j in range(n_y):
                 for k in range(n_z):
+
+                    if fisherz is True:
+                        # Fisher r to z
+                        zs = 0.5 * np.log((1 + rs) / (1 - rs))
+
                     # t test
-                    stats[t, i, j, k] = ttest_1samp(rs[t, :, i, j, k], 0)
+                    stats[t, i, j, k] = ttest_1samp(rs[t, :, i, j, k], 0, alternative="greater")
 
                     if permutation == True:
 
-                        # Fisher r to z
-                        zs = 0.5 * np.log((1 + rs) / (1 - rs))
                         stats[t, i, j, k, 1] = permutation_test(zs[t, :, i, j, k], np.zeros([npairs]), iter=iter)
 
     return stats
@@ -211,7 +224,7 @@ def stats_iscfmri(corrs, permutation=False, iter=5000):
 
 ' a function for conducting the statistical analysis for results of EEG-like data (for STPS) '
 
-def stats_stps(corrs1, corrs2, permutation=True, iter=5000):
+def stats_stps(corrs1, corrs2, fisherz=True, permutation=True, iter=5000):
 
     """
     Conduct the statistical analysis for results of EEG-like data（for STPS）
@@ -226,6 +239,8 @@ def stats_stps(corrs1, corrs2, permutation=True, iter=5000):
         The correlation coefficients under condition2.
         The shape of corrs2 must be [n_subs, n_chls, n_ts]. n_subs, n_chls, n_ts represent the number of subjects, the
         number of channels and the number of time-points.
+    fisherz : bool True or False. Default is True.
+        Conduct Fisher-Z transform.
     permutation : bool True or False. Default is False.
         Use permutation test or not.
     iter : int. Default is 5000.
@@ -265,15 +280,18 @@ def stats_stps(corrs1, corrs2, permutation=True, iter=5000):
     # calculate the statistical results
     for i in range(chls):
         for j in range(ts):
-            # t test
-            stats[i, j] = ttest_rel(rs1[:, i, j], rs2[:, i, j])
 
-            if permutation == True:
+            if fisherz is True:
 
                 # Fisher r to z
                 zs1 = 0.5*np.log((1+rs1)/(1-rs1))
                 zs2 = 0.5*np.log((1+rs2)/(1-rs2))
 
+            # t test
+            stats[i, j] = ttest_rel(rs1[:, i, j], rs2[:, i, j])
+
+            if permutation == True:
+
                 stats[i, j, 1] = permutation_test(zs1[:, i, j], zs2[:, i, j], iter=iter)
 
     return stats
@@ -281,7 +299,7 @@ def stats_stps(corrs1, corrs2, permutation=True, iter=5000):
 
 ' a function for conducting the statistical analysis for results of fMRI data (STPS searchlight) '
 
-def stats_stpsfmri(corrs1, corrs2, permutation=False, iter=5000):
+def stats_stpsfmri(corrs1, corrs2, fisherz=True, permutation=False, iter=5000):
 
     """
     Conduct the statistical analysis for results of fMRI data (STPS searchlight)
@@ -296,6 +314,8 @@ def stats_stpsfmri(corrs1, corrs2, permutation=False, iter=5000):
         The correlation coefficients under condition2.
         The shape of corrs2 must be [n_subs, n_x, n_y, n_z]. n_subs, n_x, n_y, n_z represent the number of subjects,
         the number of calculation units for searchlight along the x, y, z axis.
+    fisherz : bool True or False. Default is True.
+        Conduct Fisher-Z transform.
     permutation : bool True or False. Default is False.
         Use permutation test or not.
     iter : int. Default is 5000.
@@ -339,14 +359,17 @@ def stats_stpsfmri(corrs1, corrs2, permutation=False, iter=5000):
     for i in range(n_x):
         for j in range(n_y):
             for k in range(n_z):
-                # t test
-                stats[i, j, k] = ttest_rel(rs1[:, i, j, k], rs2[:, i, j, k])
 
-                if permutation == True:
+                if fisherz is True:
 
                     # Fisher r to z
                     zs1 = 0.5 * np.log((1 + rs1) / (1 - rs1))
                     zs2 = 0.5 * np.log((1 + rs2) / (1 - rs2))
+
+                # t test
+                stats[i, j, k] = ttest_rel(rs1[:, i, j, k], rs2[:, i, j, k])
+
+                if permutation == True:
                     stats[i, j, k, 1] = permutation_test(zs1[:, i, j, k], zs2[:, i, j, k], iter=iter)
 
     return stats
